@@ -19,11 +19,11 @@ import json
 import os
 import time
 
-from tempest import auth
-from tempest import clients
-from tempest.common import http
-from tempest.common import rest_client
 from tempest import config
+from tempest import manager
+from tempest_lib import auth
+from tempest_lib.common import http
+from tempest_lib.common import rest_client
 import testtools
 import yaml
 
@@ -69,9 +69,9 @@ CONF.register_opts(SolumGroup, group=solum_group.name)
 
 class SolumClient(rest_client.RestClient):
 
-    def __init__(self, auth_provider, service='application_deployment'):
-        super(SolumClient, self).__init__(auth_provider)
-        self.service = service
+    def __init__(self, auth_provider, service='application_deployment',
+                 region='RegionOne'):
+        super(SolumClient, self).__init__(auth_provider, service, region)
         self.endpoint_url = 'publicURL'
         self.created_assemblies = []
         self.created_plans = []
@@ -172,8 +172,7 @@ class TestCase(testtools.TestCase):
 
         credentials = SolumCredentials()
 
-        mgr = clients.Manager()
-        auth_provider = mgr.get_auth_provider(credentials)
+        auth_provider = manager.get_auth_provider(credentials)
         self.client = SolumClient(auth_provider)
         self.builderclient = SolumClient(auth_provider, 'image_builder')
 
