@@ -16,7 +16,7 @@
 
 import json
 
-from tempest import exceptions as tempest_exceptions
+from tempest_lib import exceptions as tempest_exceptions
 
 from functionaltests.api import base
 
@@ -24,7 +24,7 @@ sample_data = {"name": "test_assembly",
                "description": "A test to create assembly",
                "project_id": "project_id",
                "user_id": "user_id",
-               "status": "status",
+               "status": "QUEUED",
                "trigger_uri": "http://localhost:5000",
                "application_uri": "http://localhost:5000"}
 
