@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 #
 # Copyright 2013 - Noorul Islam K M
 #
@@ -23,5 +24,5 @@ class TestExtensionController(base.TestCase):
     def test_extensions_get_all(self):
         resp, body = self.client.get('v1/extensions')
         data = json.loads(body)
-        self.assertEqual(200, resp.status)
-        self.assertEqual([], data)
+        self.assertEqual(resp.status, 200)
+        self.assertEqual(data, [])
