@@ -18,8 +18,10 @@ import wsme
 import wsmeext.pecan as wsme_pecan
 
 from solum.api.controllers.v1.datamodel import assembly
+import solum.api.controllers.v1.userlog as userlog_controller
 from solum.api.handlers import assembly_handler
 from solum.common import exception
+from solum.common import request
 from solum import objects
 from solum.openstack.common.gettextutils import _
 
@@ -31,10 +33,19 @@ class AssemblyController(rest.RestController):
         super(AssemblyController, self).__init__()
         self._id = assembly_id
 
+    @pecan.expose()
+    def _lookup(self, primary_key, *remainder):
+        if remainder and not remainder[-1]:
+            remainder = remainder[:-1]
+        if primary_key == 'logs':
+            logs = userlog_controller.UserlogsController(self._id)
+            return logs, remainder
+
     @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(assembly.Assembly)
     def get(self):
         """Return this assembly."""
+        request.check_request_for_https()
         handler = assembly_handler.AssemblyHandler(
             pecan.request.security_context)
         return assembly.Assembly.from_db_model(handler.get(self._id),
@@ -100,6 +111,7 @@ class AssembliesController(rest.RestController):
     @wsme_pecan.wsexpose([assembly.Assembly])
     def get_all(self):
         """Return all assemblies, based on the query provided."""
+        request.check_request_for_https()
         handler = assembly_handler.AssemblyHandler(
             pecan.request.security_context)
         return [assembly.Assembly.from_db_model(assm, pecan.request.host_url)
