@@ -29,17 +29,16 @@ class InfrastructureStackController(rest.RestController):
         super(InfrastructureStackController, self).__init__()
         self._id = stack_id
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(infrastructure.InfrastructureStack)
     def get(self):
         """Return this stack."""
         handler = infrastructure_handler.InfrastructureStackHandler(
             pecan.request.security_context)
-        host_url = pecan.request.application_url.rstrip('/')
         return infrastructure.InfrastructureStack.from_db_model(
-            handler.get(self._id), host_url)
+            handler.get(self._id), pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(infrastructure.InfrastructureStack,
                          body=infrastructure.InfrastructureStack)
     def put(self, data):
@@ -49,11 +48,10 @@ class InfrastructureStackController(rest.RestController):
         res = handler.update(self._id,
                              data.as_dict(
                                  objects.registry.InfrastructureStack))
-        host_url = pecan.request.application_url.rstrip('/')
         return infrastructure.InfrastructureStack.from_db_model(
-            res, host_url)
+            res, pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(status_code=204)
     def delete(self):
         """Delete this stack."""
@@ -71,7 +69,7 @@ class InfrastructureStacksController(rest.RestController):
             remainder = remainder[:-1]
         return InfrastructureStackController(stack_id), remainder
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(infrastructure.InfrastructureStack,
                          body=infrastructure.InfrastructureStack,
                          status_code=201)
@@ -79,20 +77,18 @@ class InfrastructureStacksController(rest.RestController):
         """Create a new stack."""
         handler = infrastructure_handler.InfrastructureStackHandler(
             pecan.request.security_context)
-        host_url = pecan.request.application_url.rstrip('/')
         return infrastructure.InfrastructureStack.from_db_model(
             handler.create(data.as_dict(objects.registry.InfrastructureStack)),
-            host_url)
+            pecan.request.host_url)
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose([infrastructure.InfrastructureStack])
     def get_all(self):
         """Return all stacks, based on the query provided."""
         handler = infrastructure_handler.InfrastructureStackHandler(
             pecan.request.security_context)
-        host_url = pecan.request.application_url.rstrip('/')
         return [infrastructure.InfrastructureStack.from_db_model(
-            assm, host_url) for assm in handler.get_all()]
+            assm, pecan.request.host_url) for assm in handler.get_all()]
 
 
 class InfrastructureController(rest.RestController):
@@ -100,11 +96,10 @@ class InfrastructureController(rest.RestController):
 
     stacks = InfrastructureStacksController()
 
-    @exception.wrap_wsme_pecan_controller_exception
+    @exception.wrap_wsme_controller_exception
     @wsme_pecan.wsexpose(infrastructure.Infrastructure)
     def index(self):
-        base_url = pecan.request.application_url.rstrip('/')
-        host_url = '%s/%s' % (base_url, 'v1')
+        host_url = '%s/%s' % (pecan.request.host_url, 'v1')
         return infrastructure.Infrastructure(
             uri=host_url,
             name='solum',
