@@ -14,19 +14,19 @@
 
 import uuid
 
-import httplib2
 from oslo.config import cfg
 
 from solum.api.handlers import handler
-from solum.common import context
 from solum.common import exception
-from solum.common import solum_keystoneclient
+from solum.common import keystone_utils
+from solum.common import repo_utils
+from solum.conductor import api as conductor_api
 from solum.deployer import api as deploy_api
 from solum import objects
 from solum.objects import assembly
 from solum.objects import image
 from solum.openstack.common import log as logging
-from solum.worker import api
+from solum.worker import api as worker_api
 
 # Register options for the service
 API_SERVICE_OPTS = [
@@ -43,10 +43,7 @@ API_SERVICE_OPTS = [
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
-opt_group = cfg.OptGroup(name='api',
-                         title='Options for the solum-api service')
-CONF.register_group(opt_group)
-CONF.register_opts(API_SERVICE_OPTS, opt_group)
+CONF.register_opts(API_SERVICE_OPTS, group='api')
 
 ASSEMBLY_STATES = assembly.States
 IMAGE_STATES = image.States
@@ -59,33 +56,6 @@ class AssemblyHandler(handler.Handler):
         """Return an assembly."""
         return objects.registry.Assembly.get_by_uuid(self.context, id)
 
-    def _context_from_trust_id(self, trust_id):
-        cntx = context.RequestContext(trust_id=trust_id)
-        kc = solum_keystoneclient.KeystoneClientV3(cntx)
-        return kc.context
-
-    def _verify_artifact(self, artifact, collab_url):
-        # TODO(james_li): verify if the artifact is the one that gets triggered
-        if collab_url is None:
-            return True
-
-        repo_token = artifact.get('repo_token')
-        if repo_token is None:
-            return False
-
-        headers = {'Authorization': 'token ' + repo_token}
-        try:
-            resp, _ = httplib2.Http().request(collab_url, headers=headers)
-            if resp['status'] == '204':
-                return True
-            elif resp['status'] == '404':
-                raise exception.RequestForbidden(
-                    reason="User %s not allowed to do rebuild" %
-                           collab_url.split('/')[-1])
-        except httplib2.HttpLib2Error as ex:
-            LOG.info("Error in verifying collaborator %s" % ex)
-        return False
-
     def trigger_workflow(self, trigger_id, commit_sha='',
                          status_url=None, collab_url=None):
         """Get trigger by trigger id and start git workflow associated."""
@@ -93,9 +63,10 @@ class AssemblyHandler(handler.Handler):
         # non-authenticated request.
         db_obj = objects.registry.Assembly.get_by_trigger_id(None,
                                                              trigger_id)
-        # get the trust context and authenticate it.
         try:
-            self.context = self._context_from_trust_id(db_obj.trust_id)
+            # get the trust\impersonation context and authenticate it.
+            self.context = keystone_utils.create_delegation_context(
+                db_obj, self.context)
         except exception.AuthorizationFailure as auth_ex:
             LOG.warn(auth_ex)
             return
@@ -105,48 +76,41 @@ class AssemblyHandler(handler.Handler):
 
         artifacts = plan_obj.raw_content.get('artifacts', [])
         for arti in artifacts:
-            if self._verify_artifact(arti, collab_url):
+            if repo_utils.verify_artifact(arti, collab_url):
                 self._build_artifact(assem=db_obj, artifact=arti,
                                      commit_sha=commit_sha,
-                                     status_url=status_url,
-                                     deploy_keys_ref=plan_obj.deploy_keys_uri)
+                                     status_url=status_url)
 
     def update(self, id, data):
         """Modify a resource."""
-        db_obj = objects.registry.Assembly.get_by_uuid(self.context, id)
-        db_obj.update(data)
-        db_obj.save(self.context)
-        return db_obj
+        updated = objects.registry.Assembly.update_and_save(self.context,
+                                                            id, data)
+        return updated
 
     def delete(self, id):
         """Delete a resource."""
         db_obj = objects.registry.Assembly.get_by_uuid(self.context, id)
 
-        # delete the trust.
-        ksc = solum_keystoneclient.KeystoneClientV3(self.context)
-        ksc.delete_trust(db_obj.trust_id)
+        conductor_api.API(context=self.context).update_assembly(
+            db_obj.id, {'status': ASSEMBLY_STATES.DELETING})
 
-        db_obj.status = ASSEMBLY_STATES.DELETING
-        db_obj.save(self.context)
-
-        deploy_api.API(context=self.context).destroy(
+        deploy_api.API(context=self.context).destroy_assembly(
             assem_id=db_obj.id)
 
-    def create(self, data):
+    def create(self, data, commit_sha='', status_url=None):
         """Create a new resource."""
+        if 'workflow' in data and isinstance(data['workflow'], list):
+            data['workflow'] = list(set(data['workflow']))
+        else:
+            data['workflow'] = ['unittest', 'build', 'deploy']
         db_obj = objects.registry.Assembly()
         db_obj.update(data)
         db_obj.uuid = str(uuid.uuid4())
         db_obj.user_id = self.context.user
         db_obj.project_id = self.context.tenant
-        db_obj.trigger_id = str(uuid.uuid4())
         db_obj.username = self.context.user_name
 
-        # create the trust_id and store it.
-        ksc = solum_keystoneclient.KeystoneClientV3(self.context)
-        trust_context = ksc.create_trust_context()
-        db_obj.trust_id = trust_context.trust_id
-
+        db_obj.status = ASSEMBLY_STATES.QUEUED
         db_obj.create(self.context)
 
         plan_obj = objects.registry.Plan.get_by_id(self.context,
@@ -155,14 +119,15 @@ class AssemblyHandler(handler.Handler):
         artifacts = plan_obj.raw_content.get('artifacts', [])
         for arti in artifacts:
             self._build_artifact(assem=db_obj, artifact=arti,
-                                 deploy_keys_ref=plan_obj.deploy_keys_uri)
+                                 commit_sha=commit_sha,
+                                 status_url=status_url)
         return db_obj
 
-    def _build_artifact(self, assem, artifact, verb='build', commit_sha='',
-                        status_url=None, deploy_keys_ref=None):
+    def _build_artifact(self, assem, artifact, verb='launch_workflow',
+                        commit_sha='', status_url=None):
 
         # This is a tempory hack so we don't need the build client
-        # in the requirments.
+        # in the requirements.
         image = objects.registry.Image()
         image.name = artifact['name']
         image.source_uri = artifact['content']['href']
@@ -173,10 +138,12 @@ class AssemblyHandler(handler.Handler):
         image.uuid = str(uuid.uuid4())
         image.user_id = self.context.user
         image.project_id = self.context.tenant
-        image.state = IMAGE_STATES.PENDING
+        image.status = IMAGE_STATES.QUEUED
         image.create(self.context)
         test_cmd = artifact.get('unittest_cmd')
+        run_cmd = artifact.get('run_cmd')
         repo_token = artifact.get('repo_token')
+        ports = artifact.get('ports', [80])
 
         git_info = {
             'source_url': image.source_uri,
@@ -185,17 +152,22 @@ class AssemblyHandler(handler.Handler):
             'status_url': status_url
         }
 
-        api.API(context=self.context).perform_action(
+        if test_cmd:
+            repo_utils.send_status(0, status_url, repo_token, pending=True)
+
+        worker_api.API(context=self.context).build_app(
             verb=verb,
             build_id=image.id,
             git_info=git_info,
+            ports=ports,
             name=image.name,
             base_image_id=image.base_image_id,
             source_format=image.source_format,
             image_format=image.image_format,
             assembly_id=assem.id,
+            workflow=assem.workflow,
             test_cmd=test_cmd,
-            source_creds_ref=deploy_keys_ref)
+            run_cmd=run_cmd)
 
     def get_all(self):
         """Return all assemblies, based on the query provided."""
