@@ -178,10 +178,9 @@ class PipelineHandler(handler.Handler):
 
     def update(self, id, data):
         """Modify a resource."""
-        db_obj = objects.registry.Pipeline.get_by_uuid(self.context, id)
-        db_obj.update(data)
-        db_obj.save(self.context)
-        return db_obj
+        updated = objects.registry.Pipeline.update_and_save(self.context,
+                                                            id, data)
+        return updated
 
     def delete(self, id):
         """Delete a resource."""
