@@ -12,20 +12,15 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
-from oslo_config import cfg
+from oslo.config import cfg
 from pecan import hooks
 
 OPTS = [
     cfg.StrOpt('release',
-               default='openstack',
+               default='stackforge',
                help='The current build of Solum.'),
 ]
 
-
-def list_opts():
-    yield None, OPTS
-
-
 CONF = cfg.CONF
 CONF.register_opts(OPTS)
 
