@@ -14,15 +14,28 @@
 
 import os.path
 
+from oslo.config import cfg
+
 from solum.common import exception
 
+OPTS = [
+    cfg.StrOpt('source_path',
+               default='',
+               help='The location the source code.'),
+]
+
+CONF = cfg.CONF
+CONF.register_opts(OPTS)
+
 
 def get(entity, name, content_type='yaml'):
     """This reads a file's contents from local storage.
 
     /etc/solum/<entity>/name.<content_type>
     """
-    proj_dir = os.path.join(os.path.dirname(__file__), '..', '..')
+    proj_dir = CONF.get('source_path')
+    if not proj_dir:
+        proj_dir = os.path.join(os.path.dirname(__file__), '..', '..')
     file_path = os.path.join(proj_dir, 'etc', 'solum', entity,
                              '%s.%s' % (name, content_type))
     file_path = os.path.realpath(file_path)
@@ -32,3 +45,20 @@ def get(entity, name, content_type='yaml'):
     except Exception:
         raise exception.ObjectNotFound(
             name=entity, id=name)
+
+
+def get_from_contrib(name):
+    """This reads a file's contents from local storage.
+
+    /contrib/common/name.<content_type>
+    """
+    proj_dir = CONF.get('source_path')
+    if not proj_dir:
+        proj_dir = os.path.join(os.path.dirname(__file__), '..', '..')
+    file_path = os.path.join(proj_dir, 'contrib', 'common', '%s' % name)
+    file_path = os.path.realpath(file_path)
+    try:
+        with open(file_path) as fd:
+            return fd.read()
+    except Exception:
+        raise exception.ObjectNotFound(id=name)
