@@ -30,20 +30,19 @@ from solum.openstack.common import log as logging
 LOG = logging.getLogger(__name__)
 
 
+GLOBAL_CLIENT_OPTS = [
+    cfg.StrOpt('region_name',
+               default='RegionOne',
+               help=_(
+                   'Region of endpoint in Identity service catalog to use'
+                   ' for all clients.')),
+]
+
 barbican_client_opts = [
     cfg.BoolOpt('insecure',
                 default=False,
                 help=_("If set, then the server's certificate for barbican "
-                       "will not be verified.")),
-    cfg.StrOpt('git_secrets_file',
-               default='/etc/solum/secrets/git_secrets.db',
-               help="Tells where to store the secrets of private git repo. "
-                    "private git repo secrets location"),
-    cfg.BoolOpt('barbican_disabled',
-                default=True,
-                help="Defaults to True. If barbican is disabled, it will "
-                     "store secrets on the local filesystem specified "
-                     "by 'git_secrets_file'")]
+                       "will not be verified.")), ]
 
 # Note: this config is duplicated in many projects that use OpenStack
 # clients. This should really be in the client.
@@ -55,7 +54,11 @@ glance_client_opts = [
                default='publicURL',
                help=_(
                    'Type of endpoint in Identity service catalog to use '
-                   'for communication with the Glance service.'))]
+                   'for communication with the Glance service.')),
+    cfg.StrOpt('region_name',
+               default='',
+               help=_(
+                   'Region of endpoint in Identity service catalog to use.'))]
 
 heat_client_opts = [
     cfg.StrOpt('endpoint_type',
@@ -63,6 +66,10 @@ heat_client_opts = [
                help=_(
                    'Type of endpoint in Identity service catalog to use '
                    'for communication with the OpenStack service.')),
+    cfg.StrOpt('region_name',
+               default='',
+               help=_(
+                   'Region of endpoint in Identity service catalog to use.')),
     cfg.StrOpt('ca_file',
                help=_('Optional CA cert file to use in SSL connections.')),
     cfg.StrOpt('cert_file',
@@ -81,6 +88,10 @@ zaqar_client_opts = [
                help=_(
                    'Type of endpoint in Queue service catalog to use '
                    'for communication with the Zaqar service.')),
+    cfg.StrOpt('region_name',
+               default='',
+               help=_(
+                   'Region of endpoint in Identity service catalog to use.')),
     cfg.BoolOpt('insecure',
                 default=False,
                 help=_("If set, then the server's certificate for zaqar "
@@ -92,6 +103,10 @@ neutron_client_opts = [
                help=_(
                    'Type of endpoint in Identity service catalog to use '
                    'for communication with the Neutron service.')),
+    cfg.StrOpt('region_name',
+               default='',
+               help=_(
+                   'Region of endpoint in Identity service catalog to use.')),
     cfg.StrOpt('ca_cert',
                help=_('Optional CA bundle file to use in SSL connections.')),
     cfg.BoolOpt('insecure',
@@ -105,6 +120,10 @@ swift_client_opts = [
                help=_(
                    'Type of endpoint in Identity service catalog to use '
                    'for communication with the Swift service.')),
+    cfg.StrOpt('region_name',
+               default='',
+               help=_(
+                   'Region of endpoint in Identity service catalog to use.')),
     cfg.StrOpt('cacert',
                help=_('Optional CA cert file to use in SSL connections.')),
     cfg.BoolOpt('insecure',
@@ -117,6 +136,10 @@ mistral_client_opts = [
                help=_(
                    'Type of endpoint in Identity service catalog to use '
                    'for communication with the mistral service.')),
+    cfg.StrOpt('region_name',
+               default='',
+               help=_(
+                   'Region of endpoint in Identity service catalog to use.')),
     cfg.StrOpt('cacert',
                help=_('Optional CA cert file to use in SSL connections '
                       'with Mistral.')),
@@ -125,6 +148,7 @@ mistral_client_opts = [
                 help=_("If set the server certificate will not be verified "
                        "while using Mistral."))]
 
+cfg.CONF.register_opts(GLOBAL_CLIENT_OPTS)
 cfg.CONF.register_opts(barbican_client_opts, group='barbican_client')
 cfg.CONF.register_opts(glance_client_opts, group='glance_client')
 cfg.CONF.register_opts(heat_client_opts, group='heat_client')
@@ -134,6 +158,15 @@ cfg.CONF.register_opts(swift_client_opts, group='swift_client')
 cfg.CONF.register_opts(mistral_client_opts, group='mistral_client')
 
 
+def get_client_option(client, option):
+    value = getattr(getattr(cfg.CONF, '%s_client' % client), option)
+    if option == 'region_name':
+        global_region = cfg.CONF.get(option)
+        return value or global_region
+    else:
+        return value
+
+
 class OpenStackClients(object):
     """Convenience class to create and cache client instances."""
 
@@ -144,7 +177,6 @@ class OpenStackClients(object):
         self._glance = None
         self._heat = None
         self._neutron = None
-        self._swift = None
         self._zaqar = None
         self._mistral = None
 
@@ -153,7 +185,7 @@ class OpenStackClients(object):
 
     @property
     def auth_url(self):
-        return self.keystone().v3_endpoint
+        return self.keystone().endpoint
 
     @property
     def auth_token(self):
@@ -164,7 +196,7 @@ class OpenStackClients(object):
         if self._barbican:
             return self._barbican
 
-        insecure = self._get_client_option('barbican', 'insecure')
+        insecure = get_client_option('barbican', 'insecure')
         self._barbican = solum_barbicanclient.BarbicanClient(
             verify=not insecure)
         return self._barbican
@@ -173,7 +205,7 @@ class OpenStackClients(object):
         if self._keystone:
             return self._keystone
 
-        self._keystone = solum_keystoneclient.KeystoneClientV3(self.context)
+        self._keystone = solum_keystoneclient.KeystoneClient(self.context)
         return self._keystone
 
     @exception.wrap_keystone_exception
@@ -181,15 +213,17 @@ class OpenStackClients(object):
         if self._zaqar:
             return self._zaqar
 
-        endpoint_type = self._get_client_option('zaqar', 'endpoint_type')
+        endpoint_type = get_client_option('zaqar', 'endpoint_type')
+        region_name = get_client_option('zaqar', 'region_name')
         endpoint_url = self.url_for(service_type='queuing',
-                                    endpoint_type=endpoint_type)
+                                    endpoint_type=endpoint_type,
+                                    region_name=region_name)
         conf = {'auth_opts':
                 {'backend': 'keystone',
                  'options': {'os_auth_token': self.auth_token,
                              'os_auth_url': self.auth_url,
-                             'insecure': self._get_client_option(
-                                 'zaqar', 'insecure')}
+                             'insecure': get_client_option('zaqar',
+                                                           'insecure')}
                  }
                 }
         self._zaqar = zaqarclient.Client(endpoint_url, conf=conf)
@@ -200,24 +234,23 @@ class OpenStackClients(object):
         if self._neutron:
             return self._neutron
 
-        endpoint_type = self._get_client_option('neutron', 'endpoint_type')
+        endpoint_type = get_client_option('neutron', 'endpoint_type')
+        region_name = get_client_option('neutron', 'region_name')
         endpoint_url = self.url_for(service_type='network',
-                                    endpoint_type=endpoint_type)
+                                    endpoint_type=endpoint_type,
+                                    region_name=region_name)
         args = {
             'auth_url': self.auth_url,
             'endpoint_url': endpoint_url,
             'token': self.auth_token,
             'username': None,
             'password': None,
-            'insecure': self._get_client_option('neutron', 'insecure'),
-            'ca_cert': self._get_client_option('neutron', 'ca_cert')
+            'insecure': get_client_option('neutron', 'insecure'),
+            'ca_cert': get_client_option('neutron', 'ca_cert')
         }
         self._neutron = neutronclient.Client('2.0', **args)
         return self._neutron
 
-    def _get_client_option(self, client, option):
-        return getattr(getattr(cfg.CONF, '%s_client' % client), option)
-
     @exception.wrap_keystone_exception
     def glance(self):
         if self._glance:
@@ -226,9 +259,11 @@ class OpenStackClients(object):
         args = {
             'token': self.auth_token,
         }
-        endpoint_type = self._get_client_option('glance', 'endpoint_type')
+        endpoint_type = get_client_option('glance', 'endpoint_type')
+        region_name = get_client_option('glance', 'region_name')
         endpoint = self.url_for(service_type='image',
-                                endpoint_type=endpoint_type)
+                                endpoint_type=endpoint_type,
+                                region_name=region_name)
         self._glance = glanceclient.Client('2', endpoint, **args)
 
         return self._glance
@@ -241,9 +276,11 @@ class OpenStackClients(object):
         args = {
             'auth_token': self.auth_token,
         }
-        endpoint_type = self._get_client_option('mistral', 'endpoint_type')
+        endpoint_type = get_client_option('mistral', 'endpoint_type')
+        region_name = get_client_option('mistral', 'region_name')
         endpoint = self.url_for(service_type='workflow',
-                                endpoint_type=endpoint_type)
+                                endpoint_type=endpoint_type,
+                                region_name=region_name)
         self._mistral = mistralclient.client(mistral_url=endpoint, **args)
 
         return self._mistral
@@ -253,38 +290,42 @@ class OpenStackClients(object):
         if self._heat:
             return self._heat
 
-        endpoint_type = self._get_client_option('heat', 'endpoint_type')
+        endpoint_type = get_client_option('heat', 'endpoint_type')
         args = {
             'auth_url': self.auth_url,
             'token': self.auth_token,
             'username': None,
             'password': None,
-            'ca_file': self._get_client_option('heat', 'ca_file'),
-            'cert_file': self._get_client_option('heat', 'cert_file'),
-            'key_file': self._get_client_option('heat', 'key_file'),
-            'insecure': self._get_client_option('heat', 'insecure')
+            'ca_file': get_client_option('heat', 'ca_file'),
+            'cert_file': get_client_option('heat', 'cert_file'),
+            'key_file': get_client_option('heat', 'key_file'),
+            'insecure': get_client_option('heat', 'insecure')
         }
 
+        region_name = get_client_option('heat', 'region_name')
         endpoint = self.url_for(service_type='orchestration',
-                                endpoint_type=endpoint_type)
+                                endpoint_type=endpoint_type,
+                                region_name=region_name)
         self._heat = heatclient.Client('1', endpoint, **args)
 
         return self._heat
 
     @exception.wrap_keystone_exception
     def swift(self):
-        if self._swift:
-            return self._swift
+        # Not caching swift connections because of range requests
+        # Check how glance_store uses swift client for a reference
 
-        endpoint_type = self._get_client_option('swift', 'endpoint_type')
+        endpoint_type = get_client_option('swift', 'endpoint_type')
+        region_name = get_client_option('swift', 'region_name')
         args = {
             'auth_version': '2.0',
             'preauthtoken': self.auth_token,
             'preauthurl': self.url_for(service_type='object-store',
-                                       endpoint_type=endpoint_type),
-            'os_options': {'endpoint_type': endpoint_type},
-            'cacert': self._get_client_option('swift', 'cacert'),
-            'insecure': self._get_client_option('swift', 'insecure')
+                                       endpoint_type=endpoint_type,
+                                       region_name=region_name),
+            'os_options': {'endpoint_type': endpoint_type,
+                           'region_name': region_name},
+            'cacert': get_client_option('swift', 'cacert'),
+            'insecure': get_client_option('swift', 'insecure')
         }
-        self._swift = swiftclient.Connection(**args)
-        return self._swift
+        return swiftclient.Connection(**args)
