@@ -108,10 +108,10 @@ def wrap_controller_exception(func, func_server_error, func_client_error):
         try:
             return func(*args, **kw)
         except Exception as excp:
-            if isinstance(excp, SolumException):
+            LOG.error(excp)
+            http_error_code = 500
+            if hasattr(excp, 'code'):
                 http_error_code = excp.code
-            else:
-                http_error_code = 500
 
             if http_error_code >= 500:
                 # log the error message with its associated
@@ -122,7 +122,6 @@ def wrap_controller_exception(func, func_server_error, func_client_error):
                 func_server_error(log_correlation_id, http_error_code)
             else:
                 # raise a client error the original message
-                LOG.debug(excp)
                 func_client_error(excp, http_error_code)
     return wrapped
 
@@ -147,11 +146,30 @@ def wrap_pecan_controller_exception(func):
         pecan.response.status = status_code
         pecan.response.text = six.text_type(OBFUSCATED_MSG %
                                             log_correlation_id)
+        # message body for errors is just a plain text message
+        # The following code is functionally equivalent to calling:
+        #
+        #     pecan.override_template(None, "text/plain")
+        #
+        # We do it this way to work around a bug in our unit-test framework
+        # in which the mocked request object isn't properly mocked in the pecan
+        # core module (gilbert.plz@oracle.com)
+        pecan.request.pecan['override_template'] = None
+        pecan.request.pecan['override_content_type'] = 'text/plain'
 
     def _func_client_error(excp, status_code):
         pecan.response.status = status_code
         pecan.response.text = six.text_type(excp)
-        pecan.response.content_type = None
+
+        # The following code is functionally equivalent to calling:
+        #
+        #     pecan.override_template(None, "text/plain")
+        #
+        # We do it this way to work around a bug in our unit-test framework
+        # in which the mocked request object isn't properly mocked in the pecan
+        # core module (gilbert.plz@oracle.com)
+        pecan.request.pecan['override_template'] = None
+        pecan.request.pecan['override_content_type'] = 'text/plain'
 
     return wrap_controller_exception(func,
                                      _func_server_error,
@@ -252,11 +270,27 @@ class ResourceStillReferenced(SolumException):
     code = 409
 
 
+class UnsupportedMediaType(SolumException):
+    msg_fmt = _("\'%(name)s\' is not a supported media type for the %(method)s"
+                " method of this resource")
+    code = 415
+
+
+class Unprocessable(SolumException):
+    msg_fmt = _("Server is incapable of processing the specified request.")
+    code = 422
+
+
 class PlanStillReferenced(ResourceStillReferenced):
     msg_fmt = _("Plan %(name)s cannot be deleted because one or more"
                 " Assemblies reference it.")
 
 
+class LPStillReferenced(ResourceStillReferenced):
+    msg_fmt = _("Languagepack %(name)s cannot be deleted because one or more"
+                " applications reference it.")
+
+
 class NotImplemented(SolumException):
     msg_fmt = _("The requested operation is not implemented.")
     code = 501
@@ -264,3 +298,11 @@ class NotImplemented(SolumException):
 
 class AuthorizationFailure(SolumException):
     msg_fmt = _("%(client)s connection failed. %(message)s")
+
+
+class InvalidObjectSizeError(Exception):
+    msg_fmt = _("Invalid object size.")
+
+
+class MaxRetryReached(Exception):
+    msg_fmt = _("Maximum retries has been reached.")
