@@ -16,10 +16,10 @@ import json
 import socket
 
 import httplib2
-from oslo_config import cfg
-from oslo_log import log as logging
+from oslo.config import cfg
 
 from solum.common import exception
+from solum.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
@@ -30,11 +30,6 @@ http_timeout_opt = [
                help='Timeout value in seconds for sending http requests')
 ]
 
-
-def list_opts():
-    yield 'api', http_timeout_opt
-
-
 CONF = cfg.CONF
 CONF.register_opts(http_timeout_opt, group='api')
 
@@ -83,9 +78,8 @@ def send_status(test_result, status_url, repo_token, pending=False):
                           "status_url %s, repo_token %s" %
                           (resp['status'], status_url, repo_token))
         except (httplib2.HttpLib2Error, socket.error) as ex:
-            LOG.warning(
-                "Error in sending status, status url: %s, repo token: %s,"
-                " error: %s" % (status_url, repo_token, ex))
+            LOG.warn("Error in sending status, status url: %s, repo token: %s,"
+                     " error: %s" % (status_url, repo_token, ex))
     else:
         LOG.debug("No url or token available to send back status")
 
@@ -110,6 +104,6 @@ def verify_artifact(artifact, collab_url):
                 reason="User %s not allowed to do rebuild" %
                        collab_url.split('/')[-1])
     except (httplib2.HttpLib2Error, socket.error) as ex:
-        LOG.warning("Error in verifying collaborator, collab url: %s,"
-                    " error: %s" % (collab_url, ex))
+        LOG.warn("Error in verifying collaborator, collab url: %s,"
+                 " error: %s" % (collab_url, ex))
     return False
