@@ -15,7 +15,7 @@
 """Config options for Solum Conductor service."""
 
 
-from oslo_config import cfg
+from oslo.config import cfg
 
 SERVICE_OPTS = [
     cfg.StrOpt('topic',
@@ -29,11 +29,5 @@ SERVICE_OPTS = [
 opt_group = cfg.OptGroup(
     name='conductor',
     title='Options for the solum-conductor service')
-
-
-def list_opts():
-    yield opt_group, SERVICE_OPTS
-
-
 cfg.CONF.register_group(opt_group)
 cfg.CONF.register_opts(SERVICE_OPTS, opt_group)
