@@ -26,8 +26,12 @@ class API(service.API):
         super(API, self).__init__(transport, context,
                                   topic=cfg.CONF.deployer.topic)
 
-    def deploy(self, assembly_id, image_id):
-        self._cast('deploy', assembly_id=assembly_id, image_id=image_id)
+    def deploy(self, assembly_id, image_loc, image_name, ports):
+        self._cast('deploy', assembly_id=assembly_id, image_loc=image_loc,
+                   image_name=image_name, ports=ports)
 
-    def destroy(self, assem_id):
-        self._cast('destroy', assem_id=assem_id)
+    def destroy_assembly(self, assem_id):
+        self._cast('destroy_assembly', assem_id=assem_id)
+
+    def destroy_app(self, app_id):
+        self._cast('destroy_app', app_id=app_id)
