@@ -25,10 +25,10 @@ class ImageList(list, base.CrudListMixin):
 
 
 class States(object):
-    PENDING = 'PENDING'
+    QUEUED = 'QUEUED'
     BUILDING = 'BUILDING'
     ERROR = 'ERROR'
-    COMPLETE = 'COMPLETE'
+    READY = 'READY'
 
     @classmethod
     def as_dict(cls):
