@@ -13,13 +13,16 @@
 # under the License.
 
 import sqlalchemy as sa
+from sqlalchemy.orm import exc
 
-from solum.common import exception
 from solum import objects
 from solum.objects import assembly as abstract
 from solum.objects.sqlalchemy import component
 from solum.objects.sqlalchemy import models as sql
 
+ASSEMBLY_STATES = abstract.States
+retry = sql.retry
+
 
 class Assembly(sql.Base, abstract.Assembly):
     """Represent an assembly in sqlalchemy."""
@@ -32,8 +35,6 @@ class Assembly(sql.Base, abstract.Assembly):
     uuid = sa.Column(sa.String(36), nullable=False)
     project_id = sa.Column(sa.String(36))
     user_id = sa.Column(sa.String(36))
-    trigger_id = sa.Column(sa.String(36))
-    trust_id = sa.Column(sa.String(255))
     name = sa.Column(sa.String(100))
     description = sa.Column(sa.String(255))
     tags = sa.Column(sa.Text)
@@ -41,23 +42,18 @@ class Assembly(sql.Base, abstract.Assembly):
     status = sa.Column(sa.String(36))
     application_uri = sa.Column(sa.String(1024))
     username = sa.Column(sa.String(256))
-
-    @classmethod
-    def _raise_trigger_not_found(cls, item_id):
-        """Raise a NotFound exception."""
-        raise exception.ResourceNotFound(id=item_id, name='trigger')
-
-    @classmethod
-    def get_by_trigger_id(cls, context, trigger_id):
-        try:
-            session = sql.Base.get_session()
-            return session.query(cls).filter_by(trigger_id=trigger_id).one()
-        except sa.orm.exc.NoResultFound:
-            cls._raise_trigger_not_found(trigger_id)
+    workflow = sa.Column(sql.YAMLEncodedDict(1024))
+    image_id = sa.Column(sa.Integer)
 
     def _non_updatable_fields(self):
         return set(('uuid', 'id', 'project_id'))
 
+    def _is_updatable(self):
+        if self.status == ASSEMBLY_STATES.DELETING:
+            return False
+        else:
+            return True
+
     @property
     def plan_uuid(self):
         return objects.registry.Plan.get_by_id(None, self.plan_id).uuid
@@ -69,7 +65,7 @@ class Assembly(sql.Base, abstract.Assembly):
 
     @property
     def _extra_keys(self):
-        return ['plan_uuid']
+        return ['plan_uuid', 'created_at', 'updated_at']
 
     @property
     def components(self):
@@ -77,6 +73,7 @@ class Assembly(sql.Base, abstract.Assembly):
         return session.query(component.Component).filter_by(
             assembly_id=self.id).all()
 
+    @retry
     def destroy(self, context):
         session = sql.Base.get_session()
         with session.begin():
@@ -97,4 +94,18 @@ class AssemblyList(abstract.AssemblyList):
 
     @classmethod
     def get_all(cls, context):
-        return AssemblyList(sql.model_query(context, Assembly))
+        mq = sql.model_query(context, Assembly).order_by(
+            'updated_at desc', 'created_at desc')
+        return AssemblyList(mq)
+
+    @classmethod
+    def get_earlier(cls, assem_id, app_id, status, created_at):
+        try:
+            session = sql.Base.get_session()
+            result = session.query(Assembly)
+            result = result.filter(Assembly.plan_id == app_id)
+            result = result.filter(Assembly.status == status)
+            result = result.filter(Assembly.created_at < created_at)
+            return result.all()
+        except exc.NoResultFound:
+            cls._raise_not_found(assem_id)
