@@ -22,8 +22,7 @@ from alembic import op
 import sqlalchemy as sa
 
 from solum.objects.sqlalchemy import models
-
-from oslo_utils import timeutils
+from solum.openstack.common import timeutils
 
 # revision identifiers, used by Alembic.
 revision = '586c15b92842'
