@@ -16,7 +16,9 @@
 SQLAlchemy models for application data.
 """
 
+import functools
 import json
+import time
 
 from oslo.config import cfg
 from oslo.db import exception as db_exc
@@ -25,13 +27,35 @@ import six
 from six import moves
 from sqlalchemy import exc as sqla_exc
 from sqlalchemy.ext import declarative
-from sqlalchemy.orm import exc
+from sqlalchemy.orm import exc as orm_exc
 from sqlalchemy import types
 
 from solum.common import exception
 from solum.common import yamlutils
 from solum import objects
 from solum.objects import sqlalchemy as object_sqla
+from solum.openstack.common import log as logging
+from solum.openstack.common import uuidutils
+
+LOG = logging.getLogger(__name__)
+
+
+def retry(fun):
+    """Decorator to retry a DB call if certain exception was received."""
+    @functools.wraps(fun)
+    def _wrapper(*args, **kwargs):
+        max_retries = kwargs.pop('max_retries', 3)
+        for tries in range(max_retries):
+            try:
+                return fun(*args, **kwargs)
+            except (db_exc.DBDeadlock, orm_exc.StaleDataError):
+                LOG.warning("Failed DB call %s. Retrying %s more times." %
+                            (fun.__name__, max_retries - tries - 1))
+                if tries + 1 >= max_retries:
+                    raise
+
+                time.sleep(0.5)
+    return _wrapper
 
 
 def table_args():
@@ -51,15 +75,13 @@ def table_args():
 
 def filter_by_project(context, query):
     if context is not None:
-        is_admin = context.is_admin
-        if context.roles is not None:
-            is_admin |= 'admin' in context.roles
-        if not is_admin and context.tenant is not None:
-            try:
-                query = query.filter_by(project_id=context.tenant)
-            except sqla_exc.InvalidRequestError:
-                # No project_id column.
-                pass
+        if context.is_admin:
+            return query
+        try:
+            query = query.filter_by(project_id=context.tenant)
+        except sqla_exc.InvalidRequestError:
+            # No project_id column.
+            pass
     return query
 
 
@@ -102,7 +124,7 @@ class SolumBase(models.TimestampMixin, models.ModelBase):
             session = SolumBase.get_session()
             result = session.query(cls).filter_by(id=item_id)
             return filter_by_project(context, result).one()
-        except exc.NoResultFound:
+        except orm_exc.NoResultFound:
             cls._raise_not_found(item_id)
 
     @classmethod
@@ -111,7 +133,7 @@ class SolumBase(models.TimestampMixin, models.ModelBase):
             session = SolumBase.get_session()
             result = session.query(cls).filter_by(uuid=item_uuid)
             return filter_by_project(context, result).one()
-        except exc.NoResultFound:
+        except orm_exc.NoResultFound:
             cls._raise_not_found(item_uuid)
 
     @classmethod
@@ -128,11 +150,34 @@ class SolumBase(models.TimestampMixin, models.ModelBase):
         return any(name in d for d in (self.__dict__,
                                        self.__class__.__dict__))
 
+    def _is_updatable(self):
+        return True
+
     def update(self, data):
         for field in set(six.iterkeys(data)) - self._non_updatable_fields():
             if self._lazyhasattr(field):
                 setattr(self, field, data[field])
 
+    @classmethod  # Must be top most
+    @retry
+    def update_and_save(cls, context, id_or_uuid, data):
+        is_uuid = uuidutils.is_uuid_like(id_or_uuid)
+        try:
+            session = SolumBase.get_session()
+            with session.begin():
+                if is_uuid:
+                    query = session.query(cls).filter_by(uuid=id_or_uuid)
+                else:
+                    query = session.query(cls).filter_by(id=id_or_uuid)
+                obj = filter_by_project(context, query).one()
+                if obj._is_updatable():
+                    obj.update(data)
+                    session.merge(obj)
+            return obj
+        except orm_exc.NoResultFound:
+            cls._raise_not_found(id_or_uuid)
+
+    @retry
     def save(self, context):
         if objects.transition_schema():
             self.add_forward_schema_changes()
@@ -149,6 +194,7 @@ class SolumBase(models.TimestampMixin, models.ModelBase):
         except (db_exc.DBDuplicateEntry):
             self.__class__._raise_duplicate_object()
 
+    @retry
     def destroy(self, context):
         session = SolumBase.get_session()
         with session.begin():
