@@ -12,8 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import sqlalchemy
+import sqlalchemy as sa
 
+from solum.common import exception
 from solum.objects import plan as abstract
 from solum.objects.sqlalchemy import models as sql
 
@@ -25,15 +26,29 @@ class Plan(sql.Base, abstract.Plan):
     __tablename__ = 'plan'
     __table_args__ = sql.table_args()
 
-    id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True,
-                           autoincrement=True)
-    uuid = sqlalchemy.Column(sqlalchemy.String(36))
-    project_id = sqlalchemy.Column(sqlalchemy.String(36))
-    user_id = sqlalchemy.Column(sqlalchemy.String(36))
-    name = sqlalchemy.Column(sqlalchemy.String(255))
-    description = sqlalchemy.Column(sqlalchemy.String(255))
-    raw_content = sqlalchemy.Column(sql.YAMLEncodedDict(2048))
-    deploy_keys_uri = sqlalchemy.Column(sqlalchemy.String(1024))
+    id = sa.Column(sa.Integer, primary_key=True, autoincrement=True)
+    uuid = sa.Column(sa.String(36))
+    project_id = sa.Column(sa.String(36))
+    user_id = sa.Column(sa.String(36))
+    name = sa.Column(sa.String(255))
+    description = sa.Column(sa.String(255))
+    raw_content = sa.Column(sql.YAMLEncodedDict(2048))
+    trigger_id = sa.Column(sa.String(36))
+    trust_id = sa.Column(sa.String(255))
+    username = sa.Column(sa.String(256))
+
+    @classmethod
+    def _raise_trigger_not_found(cls, item_id):
+        """Raise a NotFound exception."""
+        raise exception.ResourceNotFound(id=item_id, name='trigger')
+
+    @classmethod
+    def get_by_trigger_id(cls, context, trigger_id):
+        try:
+            session = sql.Base.get_session()
+            return session.query(cls).filter_by(trigger_id=trigger_id).one()
+        except sa.orm.exc.NoResultFound:
+            cls._raise_trigger_not_found(trigger_id)
 
     def _non_updatable_fields(self):
         return set(('uuid', 'id', 'project_id'))
