@@ -33,11 +33,13 @@ class ClientsTest(base.BaseTestCase):
     @mock.patch.object(clients.OpenStackClients, 'keystone')
     def test_url_for(self, mock_keystone):
         obj = clients.OpenStackClients(None)
-        obj.url_for(service_type='fake_service', endpoint_type='fake_endpoint')
+        obj.url_for(service_type='fake_service', endpoint_type='fake_endpoint',
+                    region_name='FakeRegion')
 
         mock_cat = mock_keystone.return_value.client.service_catalog
         mock_cat.url_for.assert_called_once_with(service_type='fake_service',
-                                                 endpoint_type='fake_endpoint')
+                                                 endpoint_type='fake_endpoint',
+                                                 region_name='FakeRegion')
 
     @mock.patch.object(barbicanclient, 'Client')
     @mock.patch.object(session, 'Session')
@@ -61,8 +63,14 @@ class ClientsTest(base.BaseTestCase):
         cfg.CONF.set_override('admin_tenant_name', 'service',
                               group='keystone_authtoken')
         obj = clients.OpenStackClients(None)
-        self.assertRaises(exceptions.ConnectionRefused,
-                          lambda: obj.barbican().admin_client)
+
+        # try to create and store a secret
+        try:
+            bclient = obj.barbican().admin_client
+            secret = bclient.secrets.create(name="test", payload="test")
+            secret.store()
+        except exceptions.ConnectionRefused:
+            self.assertTrue(True)
 
     @mock.patch.object(barbicanclient, 'Client')
     @mock.patch.object(identity_v2, 'Password')
@@ -90,7 +98,8 @@ class ClientsTest(base.BaseTestCase):
         mock_call.assert_called_once_with(
             '2', 'url_from_keystone', token='3bcc3d3a03f44e3d8377f9247b0ad155')
         mock_url.assert_called_once_with(service_type='image',
-                                         endpoint_type='publicURL')
+                                         endpoint_type='publicURL',
+                                         region_name='RegionOne')
 
     def test_clients_glance_noauth(self):
         con = mock.MagicMock()
@@ -133,7 +142,8 @@ class ClientsTest(base.BaseTestCase):
             auth_url='keystone_url', ca_file=None, key_file=None,
             password=None, insecure=False)
         mock_url.assert_called_once_with(service_type='orchestration',
-                                         endpoint_type='publicURL')
+                                         endpoint_type='publicURL',
+                                         region_name='RegionOne')
 
     def test_clients_heat_noauth(self):
         con = mock.MagicMock()
@@ -175,7 +185,9 @@ class ClientsTest(base.BaseTestCase):
         obj._swift = None
         obj.swift()
         mock_call.assert_called_once_with(
-            auth_version="2.0", os_options={'endpoint_type': 'publicURL'},
+            auth_version="2.0",
+            os_options={'endpoint_type': 'publicURL',
+                        'region_name': 'RegionOne'},
             cacert=None, preauthurl="url_from_keystone", insecure=False,
             preauthtoken="3bcc3d3a03f44e3d8377f9247b0ad155")
 
@@ -195,7 +207,7 @@ class ClientsTest(base.BaseTestCase):
 
     @mock.patch.object(clients.OpenStackClients, 'url_for')
     @mock.patch.object(clients.OpenStackClients, 'auth_url')
-    def test_clients_swift_cached(self, mock_auth, mock_url):
+    def test_clients_swift_not_cached(self, mock_auth, mock_url):
         mock_auth.__get__ = mock.Mock(return_value="keystone_url")
         con = mock.MagicMock()
         con.tenant = "b363706f891f48019483f8bd6503c54b"
@@ -205,7 +217,7 @@ class ClientsTest(base.BaseTestCase):
         obj._swift = None
         swift = obj.swift()
         swift_cached = obj.swift()
-        self.assertEqual(swift, swift_cached)
+        self.assertNotEqual(swift, swift_cached)
 
     @mock.patch.object(neutronclient, 'Client')
     @mock.patch.object(clients.OpenStackClients, 'url_for')
@@ -267,7 +279,8 @@ class ClientsTest(base.BaseTestCase):
             mistral_url='url_from_keystone',
             auth_token='3bcc3d3a03f44e3d8377f9247b0ad155')
         mock_url.assert_called_once_with(service_type='workflow',
-                                         endpoint_type='publicURL')
+                                         endpoint_type='publicURL',
+                                         region_name='RegionOne')
 
     def test_clients_mistral_noauth(self):
         con = mock.MagicMock()
