@@ -12,6 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import datetime
+
 import mock
 
 from solum.openstack.common import uuidutils
@@ -41,10 +43,13 @@ class FakePecanRequest(mock.Mock):
         self.context = {}
         self.body = ''
         self.content_type = 'text/unicode'
+        self.accept = None
         self.params = {}
         self.path = '/v1/services'
         self.headers = fakeAuthTokenHeaders
         self.environ = {}
+        self.pecan = dict(content_type=None)
+        self.query_string = ''
 
     def __setitem__(self, index, value):
         setattr(self, index, value)
@@ -204,7 +209,11 @@ class FakeAssembly(mock.Mock):
         self.components = [FakeComponent()]
         self.status = 'BUILDING'
         self.application_uri = 'test_uri'
-        self.trust_id = 'trust_worthy'
+        now = datetime.datetime.utcnow()
+        self.created_at = now
+        self.updated_at = now
+        self.workflow = ['unittest', 'build', 'deploy']
+        self.image_id = 8
 
     def as_dict(self):
         return dict(user_id=self.user_id,
@@ -213,7 +222,10 @@ class FakeAssembly(mock.Mock):
                     uuid=self.uuid,
                     id=self.id,
                     name=self.name,
-                    status=self.status)
+                    created_at=self.created_at,
+                    updated_at=self.updated_at,
+                    status=self.status,
+                    workflow=self.workflow)
 
 
 class FakePipeline(mock.Mock):
@@ -245,13 +257,15 @@ class FakePlan(mock.Mock):
         super(FakePlan, self).__init__(**kwargs)
         self.__tablename__ = 'plan'
         self.__resource__ = 'plans'
-        self.raw_content = {'name': 'faker', 'artifacts': []}
+        self.raw_content = ({'name': 'faker',
+                            'artifacts': [{'language_pack': 'test_lp'}]})
         self.user_id = 'fake user id'
         self.project_id = 'fake_project_id'
         self.uuid = 'test_uuid'
         self.id = 8
         self.name = 'faker'
         self.deploy_keys_uri = None
+        self.trust_id = 'trust_worthy'
 
     def as_dict(self):
         return dict(raw_content=self.raw_content,
@@ -283,6 +297,10 @@ class FakeImage(mock.Mock):
         self.created_image_id = '7-2-3-4'
         self.image_format = 'docker'
         self.source_format = 'dib'
+        self.artifact_type = None
+        self.status = 'READY'
+        self.external_ref = 'TempUrl'
+        self.docker_image_name = 'tenant-name-ts-commit'
 
     def as_dict(self):
         return dict(user_id=self.user_id,
@@ -360,7 +378,8 @@ class FakeAttributeDefinition(mock.Mock):
 class FakeUserlog(mock.Mock):
     def __init__(self, **kwargs):
         super(FakeUserlog, self).__init__(**kwargs)
-        self.assembly_uuid = uuidutils.generate_uuid()
+        self.resource_uuid = uuidutils.generate_uuid()
+        self.resource_type = 'app'
         self.location = 'fake location'
         self.strategy = 'local'
         self.strategy_info = '{}'
