@@ -26,14 +26,17 @@ class API(service.API):
         super(API, self).__init__(transport, context,
                                   topic=cfg.CONF.worker.topic)
 
-    def perform_action(self, verb, build_id, git_info, name, base_image_id,
-                       source_format, image_format, assembly_id=None,
-                       test_cmd=None, source_creds_ref=None,
-                       artifact_type=None, lp_metadata=None):
-        self._cast(verb, build_id=build_id, git_info=git_info,
+    def build_app(self, verb, build_id, git_info, ports, name, base_image_id,
+                  source_format, image_format, assembly_id, workflow,
+                  test_cmd=None, run_cmd=None):
+        self._cast(verb, build_id=build_id, git_info=git_info, ports=ports,
                    name=name, base_image_id=base_image_id,
                    source_format=source_format, image_format=image_format,
-                   assembly_id=assembly_id, test_cmd=test_cmd,
-                   source_creds_ref=source_creds_ref,
-                   artifact_type=artifact_type,
-                   lp_metadata=lp_metadata)
+                   assembly_id=assembly_id, workflow=workflow,
+                   test_cmd=test_cmd, run_cmd=run_cmd)
+
+    def build_lp(self, image_id, git_info, name, source_format, image_format,
+                 artifact_type):
+        self._cast('build_lp', image_id=image_id, git_info=git_info, name=name,
+                   source_format=source_format, image_format=image_format,
+                   artifact_type=artifact_type)
